You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@wicket.apache.org by jc...@apache.org on 2007/04/10 20:16:39 UTC

svn commit: r527232 [5/28] - in /incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src: main/java/ main/java/org/ main/java/org/apache/ main/java/org/apache/wicket/ main/java/org/apache/wicket/ajax/ main/java/org/apache/wicket/ajax/calldecorator/ mai...

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupElement.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupElement.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupElement.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupElement.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupElement.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupElement.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupElement.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
 /**
  * Base class for different kinds of markup elements.  Markup elements are 
@@ -28,7 +28,7 @@
  * </ul>
  *
  * @see Markup
- * @see wicket.markup.RawMarkup
+ * @see org.apache.wicket.markup.RawMarkup
  * @see ComponentTag
  * @author Jonathan Locke
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupException.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupException.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupException.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupException.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupException.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupException.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupException.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
-import wicket.WicketRuntimeException;
-import wicket.util.resource.IResourceStream;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.util.resource.IResourceStream;
 
 /**
  * Runtime exception that is thrown when markup parsing fails.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupFragment.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupFragment.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupFragment.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupFragment.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupFragment.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupFragment.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupFragment.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
 import java.util.ArrayList;
 import java.util.Collections;
@@ -23,17 +23,17 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.util.string.AppendingStringBuffer;
 
-import wicket.util.string.AppendingStringBuffer;
 
 /**
  * A list of markup elements associated with a Markup. Might be all elements of
  * a markup resource, might be just the elements associated with a specific tag.
  * 
- * @see wicket.markup.Markup
- * @see wicket.markup.MarkupElement
- * @see wicket.markup.ComponentTag
- * @see wicket.markup.RawMarkup
+ * @see org.apache.wicket.markup.Markup
+ * @see org.apache.wicket.markup.MarkupElement
+ * @see org.apache.wicket.markup.ComponentTag
+ * @see org.apache.wicket.markup.RawMarkup
  * 
  * @author Juergen Donnerstag
  */
@@ -83,7 +83,7 @@
 
 	/**
 	 * For Wicket it would be sufficient for this method to be package
-	 * protected. However to allow wicket-bench easy access to the information
+	 * protected. However to allow org.apache.wicket-bench easy access to the information
 	 * ...
 	 * 
 	 * @param index
@@ -107,7 +107,7 @@
 
 	/**
 	 * For Wicket it would be sufficient for this method to be package
-	 * protected. However to allow wicket-bench easy access to the information
+	 * protected. However to allow org.apache.wicket-bench easy access to the information
 	 * ...
 	 * 
 	 * @return Number of markup elements
@@ -157,7 +157,7 @@
 	}
 
 	/**
-	 * Reset the markup to its defaults, except for the wicket namespace which
+	 * Reset the markup to its defaults, except for the org.apache.wicket namespace which
 	 * remains unchanged.
 	 */
 	final void reset()

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupNotFoundException.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupNotFoundException.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupNotFoundException.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupNotFoundException.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupNotFoundException.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupNotFoundException.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupNotFoundException.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
-import wicket.WicketRuntimeException;
+import org.apache.wicket.WicketRuntimeException;
 
 /**
  * Runtime exception that is thrown when markup file was not found.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupParser.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupParser.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupParser.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupParser.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupParser.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupParser.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupParser.java Tue Apr 10 11:15:14 2007
@@ -14,30 +14,31 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
 import java.io.IOException;
 import java.text.ParseException;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import wicket.Application;
-import wicket.Page;
-import wicket.markup.parser.IMarkupFilter;
-import wicket.markup.parser.IXmlPullParser;
-import wicket.markup.parser.filter.BodyOnLoadHandler;
-import wicket.markup.parser.filter.HeadForceTagIdHandler;
-import wicket.markup.parser.filter.HtmlHandler;
-import wicket.markup.parser.filter.HtmlHeaderSectionHandler;
-import wicket.markup.parser.filter.TagTypeHandler;
-import wicket.markup.parser.filter.WicketLinkTagHandler;
-import wicket.markup.parser.filter.WicketMessageTagHandler;
-import wicket.markup.parser.filter.WicketNamespaceHandler;
-import wicket.markup.parser.filter.WicketRemoveTagHandler;
-import wicket.markup.parser.filter.WicketTagIdentifier;
-import wicket.settings.IMarkupSettings;
-import wicket.util.resource.ResourceStreamNotFoundException;
-import wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.Application;
+import org.apache.wicket.Page;
+import org.apache.wicket.markup.parser.IMarkupFilter;
+import org.apache.wicket.markup.parser.IXmlPullParser;
+import org.apache.wicket.markup.parser.filter.BodyOnLoadHandler;
+import org.apache.wicket.markup.parser.filter.HeadForceTagIdHandler;
+import org.apache.wicket.markup.parser.filter.HtmlHandler;
+import org.apache.wicket.markup.parser.filter.HtmlHeaderSectionHandler;
+import org.apache.wicket.markup.parser.filter.TagTypeHandler;
+import org.apache.wicket.markup.parser.filter.WicketLinkTagHandler;
+import org.apache.wicket.markup.parser.filter.WicketMessageTagHandler;
+import org.apache.wicket.markup.parser.filter.WicketNamespaceHandler;
+import org.apache.wicket.markup.parser.filter.WicketRemoveTagHandler;
+import org.apache.wicket.markup.parser.filter.WicketTagIdentifier;
+import org.apache.wicket.settings.IMarkupSettings;
+import org.apache.wicket.util.resource.ResourceStreamNotFoundException;
+import org.apache.wicket.util.string.AppendingStringBuffer;
+
 
 
 /**
@@ -88,7 +89,7 @@
 	}
 
 	/**
-	 * In case you want to analyze markup which BY DEFAULT does not use "wicket"
+	 * In case you want to analyze markup which BY DEFAULT does not use "org.apache.wicket"
 	 * to find relevant tags.
 	 * 
 	 * @param namespace
@@ -125,7 +126,7 @@
 		appendMarkupFilter(new WicketLinkTagHandler());
 		appendMarkupFilter(new WicketNamespaceHandler(markup));
 
-		// Provided the wicket component requesting the markup is known ...
+		// Provided the org.apache.wicket component requesting the markup is known ...
 		final MarkupResourceStream resource = markup.getResource();
 		if (resource != null)
 		{
@@ -190,7 +191,7 @@
 		// Initialize the xml parser
 		this.xmlParser.parse(resource.getInputStream(), this.markupSettings.getDefaultMarkupEncoding());
 
-		// parse the xml markup and tokenize it into wicket relevant markup
+		// parse the xml markup and tokenize it into org.apache.wicket relevant markup
 		// elements
 		parseMarkup();
 
@@ -218,7 +219,7 @@
 		// Initialize the xml parser
 		this.xmlParser.parse(string);
 
-		// parse the xml markup and tokenize it into wicket relevant markup
+		// parse the xml markup and tokenize it into org.apache.wicket relevant markup
 		// elements
 		parseMarkup();
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupParserFactory.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupParserFactory.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupParserFactory.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupParserFactory.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupParserFactory.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupParserFactory.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupParserFactory.java Tue Apr 10 11:15:14 2007
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
-import wicket.Application;
-import wicket.markup.parser.IMarkupFilter;
-import wicket.markup.parser.XmlPullParser;
-import wicket.markup.parser.filter.EnclosureHandler;
-import wicket.markup.parser.filter.PrependContextPathHandler;
+import org.apache.wicket.Application;
+import org.apache.wicket.markup.parser.IMarkupFilter;
+import org.apache.wicket.markup.parser.XmlPullParser;
+import org.apache.wicket.markup.parser.filter.EnclosureHandler;
+import org.apache.wicket.markup.parser.filter.PrependContextPathHandler;
 
 /**
  * Default implementation of IMarkupParserFactory
@@ -77,7 +77,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.IMarkupParserFactory#newMarkupParser()
+	 * @see org.apache.wicket.markup.IMarkupParserFactory#newMarkupParser()
 	 */
 	public MarkupParser newMarkupParser()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupResourceStream.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupResourceStream.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupResourceStream.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupResourceStream.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupResourceStream.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupResourceStream.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupResourceStream.java Tue Apr 10 11:15:14 2007
@@ -14,15 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.Locale;
 
-import wicket.util.resource.IResourceStream;
-import wicket.util.resource.ResourceStreamNotFoundException;
-import wicket.util.time.Time;
+import org.apache.wicket.util.resource.IResourceStream;
+import org.apache.wicket.util.resource.ResourceStreamNotFoundException;
+import org.apache.wicket.util.time.Time;
+
 
 /**
  * An IResourceStream implementation with specific extensions for markup
@@ -74,7 +75,7 @@
 
 	/**
 	 * 
-	 * @see wicket.util.resource.IResourceStream#close()
+	 * @see org.apache.wicket.util.resource.IResourceStream#close()
 	 */
 	public void close() throws IOException
 	{
@@ -83,7 +84,7 @@
 
 	/**
 	 * 
-	 * @see wicket.util.resource.IResourceStream#getContentType()
+	 * @see org.apache.wicket.util.resource.IResourceStream#getContentType()
 	 */
 	public String getContentType()
 	{
@@ -92,7 +93,7 @@
 
 	/**
 	 * 
-	 * @see wicket.util.resource.IResourceStream#getInputStream()
+	 * @see org.apache.wicket.util.resource.IResourceStream#getInputStream()
 	 */
 	public InputStream getInputStream() throws ResourceStreamNotFoundException
 	{
@@ -101,7 +102,7 @@
 
 	/**
 	 * 
-	 * @see wicket.util.resource.IResourceStream#getLocale()
+	 * @see org.apache.wicket.util.resource.IResourceStream#getLocale()
 	 */
 	public Locale getLocale()
 	{
@@ -110,7 +111,7 @@
 
 	/**
 	 * 
-	 * @see wicket.util.watch.IModifiable#lastModifiedTime()
+	 * @see org.apache.wicket.util.watch.IModifiable#lastModifiedTime()
 	 */
 	public Time lastModifiedTime()
 	{
@@ -119,7 +120,7 @@
 
 	/**
 	 * 
-	 * @see wicket.util.resource.IResourceStream#length()
+	 * @see org.apache.wicket.util.resource.IResourceStream#length()
 	 */
 	public long length()
 	{
@@ -128,7 +129,7 @@
 
 	/**
 	 * 
-	 * @see wicket.util.resource.IResourceStream#setLocale(java.util.Locale)
+	 * @see org.apache.wicket.util.resource.IResourceStream#setLocale(java.util.Locale)
 	 */
 	public void setLocale(Locale locale)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupStream.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupStream.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupStream.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupStream.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupStream.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/RawMarkup.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/RawMarkup.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
 /**
  * This class is for framework purposes only, which is why the class is
@@ -78,7 +78,7 @@
     }
 
     /**
-     * @see wicket.markup.MarkupElement#toCharSequence()
+     * @see org.apache.wicket.markup.MarkupElement#toCharSequence()
      */
     public CharSequence toCharSequence()
     {

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/TagUtils.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/TagUtils.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/TagUtils.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/TagUtils.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/TagUtils.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/TagUtils.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/TagUtils.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/WicketTag.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/WicketTag.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/WicketTag.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/WicketTag.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/WicketTag.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/WicketTag.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/WicketTag.java Tue Apr 10 11:15:14 2007
@@ -14,20 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
-import wicket.markup.parser.XmlTag;
+import org.apache.wicket.markup.parser.XmlTag;
 
 /**
  * WicketTag extends ComponentTag and will be created by a MarkupParser whenever
- * it parses a tag in the wicket namespace. By default, this namespace is
- * "wicket", so wicket tags are then of the form &lt;wicket:*&gt;
+ * it parses a tag in the org.apache.wicket namespace. By default, this namespace is
+ * "org.apache.wicket", so org.apache.wicket tags are then of the form &lt;org.apache.wicket:*&gt;
  * <p>
  * Note 1: you need to add an XHTML doctype to your markup and use &lt;html
- * xmlns:wicket&gt; to create a XHTML conformant namespace for such tags.
+ * xmlns:org.apache.wicket&gt; to create a XHTML conformant namespace for such tags.
  * <p>
  * Note 2: The namespace name is configurable. E.g. &lt;html
- * xmlns:wcn="http://wicket.sourcefourge.net"&gt;
+ * xmlns:wcn="http://org.apache.wicket.sourcefourge.net"&gt;
  * 
  * @author Juergen Donnerstag
  */
@@ -45,7 +45,7 @@
 	}
 
 	/**
-	 * Get the tag's name attribute: e.g. &lt;wicket:region name=panel&gt;
+	 * Get the tag's name attribute: e.g. &lt;org.apache.wicket:region name=panel&gt;
 	 * 
 	 * @return The tag's name attribute
 	 */
@@ -55,7 +55,7 @@
 	}
 
 	/**
-	 * @return True, if tag name equals 'wicket:component'
+	 * @return True, if tag name equals 'org.apache.wicket:component'
 	 */
 	public final boolean isComponentTag()
 	{
@@ -63,7 +63,7 @@
 	}
 
 	/**
-	 * @return True, if tag name equals 'wicket:link'
+	 * @return True, if tag name equals 'org.apache.wicket:link'
 	 */
 	public final boolean isLinkTag()
 	{
@@ -71,7 +71,7 @@
 	}
 
 	/**
-	 * @return True, if tag name equals 'wicket:remove'
+	 * @return True, if tag name equals 'org.apache.wicket:remove'
 	 */
 	public final boolean isRemoveTag()
 	{
@@ -79,7 +79,7 @@
 	}
 
 	/**
-	 * @return True, if tag name equals 'wicket:body'
+	 * @return True, if tag name equals 'org.apache.wicket:body'
 	 */
 	public final boolean isBodyTag()
 	{
@@ -87,7 +87,7 @@
 	}
 
 	/**
-	 * @return True, if tag name equals 'wicket:container'
+	 * @return True, if tag name equals 'org.apache.wicket:container'
 	 */
 	public final boolean isContainerTag()
 	{
@@ -95,7 +95,7 @@
 	}
 
 	/**
-	 * @return True, if tag name equals 'wicket:child'
+	 * @return True, if tag name equals 'org.apache.wicket:child'
 	 */
 	public final boolean isChildTag()
 	{
@@ -103,7 +103,7 @@
 	}
 
 	/**
-	 * @return True, if tag name equals 'wicket:extend'
+	 * @return True, if tag name equals 'org.apache.wicket:extend'
 	 */
 	public final boolean isExtendTag()
 	{
@@ -111,7 +111,7 @@
 	}
 
 	/**
-	 * @return True, if tag name equals 'wicket:extend'
+	 * @return True, if tag name equals 'org.apache.wicket:extend'
 	 */
 	public final boolean isHeadTag()
 	{
@@ -119,7 +119,7 @@
 	}
 
 	/**
-	 * @return True, if tag name equals 'wicket:message'
+	 * @return True, if tag name equals 'org.apache.wicket:message'
 	 */
 	public final boolean isMessageTag()
 	{
@@ -127,7 +127,7 @@
 	}
 
 	/**
-	 * @return True, if tag name equals 'wicket:panel'
+	 * @return True, if tag name equals 'org.apache.wicket:panel'
 	 */
 	public final boolean isPanelTag()
 	{
@@ -135,7 +135,7 @@
 	}
 
 	/**
-	 * @return True, if tag name equals 'wicket:border'
+	 * @return True, if tag name equals 'org.apache.wicket:border'
 	 */
 	public final boolean isBorderTag()
 	{
@@ -143,7 +143,7 @@
 	}
 
 	/**
-	 * @return True if &lt;wicket:fragment&gt;
+	 * @return True if &lt;org.apache.wicket:fragment&gt;
 	 */
 	public final boolean isFragementTag()
 	{
@@ -151,7 +151,7 @@
 	}
 
 	/**
-	 * @return true if &lt;wicket:enclsoure&gt;
+	 * @return true if &lt;org.apache.wicket:enclsoure&gt;
 	 */
 	public final boolean isEnclosureTag()
 	{
@@ -159,7 +159,7 @@
 	}
 
 	/**
-	 * @return True if <wicket:panel>, <wicket:border>, <wicket:ex
+	 * @return True if <org.apache.wicket:panel>, <org.apache.wicket:border>, <org.apache.wicket:ex
 	 */
 	public final boolean isMajorWicketComponentTag()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/AjaxServerAndClientTimeFilter.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/AjaxServerAndClientTimeFilter.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/AjaxServerAndClientTimeFilter.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/AjaxServerAndClientTimeFilter.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/AjaxServerAndClientTimeFilter.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/AjaxServerAndClientTimeFilter.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/AjaxServerAndClientTimeFilter.java Tue Apr 10 11:15:14 2007
@@ -14,20 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
 import java.util.HashMap;
 import java.util.Map;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Application;
+import org.apache.wicket.IResponseFilter;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.model.Model;
+import org.apache.wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.util.string.JavascriptUtils;
 
-import wicket.Application;
-import wicket.IResponseFilter;
-import wicket.RequestCycle;
-import wicket.model.Model;
-import wicket.util.string.AppendingStringBuffer;
-import wicket.util.string.JavascriptUtils;
 
 /**
  * This is a filter that injects javascript code to the top head portion and
@@ -48,7 +48,7 @@
 	private static Log log = LogFactory.getLog(AjaxServerAndClientTimeFilter.class);
 
 	/**
-	 * @see wicket.IResponseFilter#filter(java.lang.StringBuffer)
+	 * @see org.apache.wicket.IResponseFilter#filter(java.lang.StringBuffer)
 	 */
 	public AppendingStringBuffer filter(AppendingStringBuffer responseBuffer)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/BodyContainer.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/BodyContainer.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/BodyContainer.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/BodyContainer.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/BodyContainer.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/BodyContainer.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/BodyContainer.java Tue Apr 10 11:15:14 2007
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
-import wicket.AttributeModifier;
-import wicket.Component;
-import wicket.IClusterable;
-import wicket.markup.html.body.BodyTagAttributeModifier;
-import wicket.model.IModel;
-import wicket.model.Model;
+import org.apache.wicket.AttributeModifier;
+import org.apache.wicket.Component;
+import org.apache.wicket.IClusterable;
+import org.apache.wicket.markup.html.body.BodyTagAttributeModifier;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.model.Model;
 
 /**
  * This is not realy a Container component in the standard Wicket sense. It

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/CompressedPackageResource.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/CompressedPackageResource.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/CompressedPackageResource.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/CompressedPackageResource.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/CompressedPackageResource.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/CompressedPackageResource.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/CompressedPackageResource.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
@@ -24,16 +24,17 @@
 import java.util.Locale;
 import java.util.zip.GZIPOutputStream;
 
-import wicket.Application;
-import wicket.SharedResources;
-import wicket.markup.html.resources.CompressedResourceReference;
-import wicket.protocol.http.WebRequest;
-import wicket.protocol.http.WebRequestCycle;
-import wicket.protocol.http.WebResponse;
-import wicket.util.io.Streams;
-import wicket.util.resource.IResourceStream;
-import wicket.util.resource.ResourceStreamNotFoundException;
-import wicket.util.time.Time;
+import org.apache.wicket.Application;
+import org.apache.wicket.SharedResources;
+import org.apache.wicket.markup.html.resources.CompressedResourceReference;
+import org.apache.wicket.protocol.http.WebRequest;
+import org.apache.wicket.protocol.http.WebRequestCycle;
+import org.apache.wicket.protocol.http.WebResponse;
+import org.apache.wicket.util.io.Streams;
+import org.apache.wicket.util.resource.IResourceStream;
+import org.apache.wicket.util.resource.ResourceStreamNotFoundException;
+import org.apache.wicket.util.time.Time;
+
 
 /**
  * Identical to PackageResource, but supports gzip compression of data
@@ -59,14 +60,14 @@
 		private Time timeStamp = null;
 
 		/**
-		 * @see wicket.util.resource.IResourceStream#close()
+		 * @see org.apache.wicket.util.resource.IResourceStream#close()
 		 */
 		public void close() throws IOException
 		{
 		}
 
 		/**
-		 * @see wicket.util.resource.IResourceStream#getContentType()
+		 * @see org.apache.wicket.util.resource.IResourceStream#getContentType()
 		 */
 		public String getContentType()
 		{
@@ -74,7 +75,7 @@
 		}
 
 		/**
-		 * @see wicket.util.resource.IResourceStream#getInputStream()
+		 * @see org.apache.wicket.util.resource.IResourceStream#getInputStream()
 		 */
 		public InputStream getInputStream() throws ResourceStreamNotFoundException
 		{
@@ -89,7 +90,7 @@
 		}
 
 		/**
-		 * @see wicket.util.resource.IResourceStream#getLocale()
+		 * @see org.apache.wicket.util.resource.IResourceStream#getLocale()
 		 */
 		public Locale getLocale()
 		{
@@ -97,7 +98,7 @@
 		}
 
 		/**
-		 * @see wicket.util.watch.IModifiable#lastModifiedTime()
+		 * @see org.apache.wicket.util.watch.IModifiable#lastModifiedTime()
 		 */
 		public Time lastModifiedTime()
 		{
@@ -105,7 +106,7 @@
 		}
 
 		/**
-		 * @see wicket.util.resource.IResourceStream#length()
+		 * @see org.apache.wicket.util.resource.IResourceStream#length()
 		 */
 		public long length()
 		{
@@ -120,7 +121,7 @@
 		}
 
 		/**
-		 * @see wicket.util.resource.IResourceStream#setLocale(java.util.Locale)
+		 * @see org.apache.wicket.util.resource.IResourceStream#setLocale(java.util.Locale)
 		 */
 		public void setLocale(Locale locale)
 		{
@@ -182,7 +183,7 @@
 	 * @param locale
 	 *            The locale of the resource
 	 * @param style
-	 *            The style of the resource (see {@link wicket.Session})
+	 *            The style of the resource (see {@link org.apache.wicket.Session})
 	 * @return The resource
 	 * @throws PackageResourceBlockedException
 	 *             when the target resource is not accepted by
@@ -251,7 +252,7 @@
 	 * IResourceStream implementation which compresses the data with gzip if the
 	 * requests header Accept-Encoding contains string gzip
 	 * 
-	 * @see wicket.markup.html.PackageResource#getResourceStream()
+	 * @see org.apache.wicket.markup.html.PackageResource#getResourceStream()
 	 */
 	public IResourceStream getResourceStream()
 	{
@@ -276,7 +277,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.WebResource#setHeaders(wicket.protocol.http.WebResponse)
+	 * @see org.apache.wicket.markup.html.WebResource#setHeaders(org.apache.wicket.protocol.http.WebResponse)
 	 */
 	protected void setHeaders(WebResponse response)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/ContainerWithAssociatedMarkupHelper.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/ContainerWithAssociatedMarkupHelper.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/ContainerWithAssociatedMarkupHelper.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/ContainerWithAssociatedMarkupHelper.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/ContainerWithAssociatedMarkupHelper.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/ContainerWithAssociatedMarkupHelper.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/ContainerWithAssociatedMarkupHelper.java Tue Apr 10 11:15:14 2007
@@ -14,26 +14,27 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
 import java.util.Iterator;
 
-import wicket.Response;
-import wicket.WicketRuntimeException;
-import wicket.behavior.AbstractBehavior;
-import wicket.markup.ComponentTag;
-import wicket.markup.MarkupElement;
-import wicket.markup.MarkupException;
-import wicket.markup.MarkupStream;
-import wicket.markup.TagUtils;
-import wicket.markup.WicketTag;
-import wicket.markup.html.internal.HtmlHeaderContainer;
-import wicket.response.NullResponse;
-import wicket.util.lang.Classes;
-import wicket.util.value.IValueMap;
+import org.apache.wicket.Response;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.behavior.AbstractBehavior;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.MarkupElement;
+import org.apache.wicket.markup.MarkupException;
+import org.apache.wicket.markup.MarkupStream;
+import org.apache.wicket.markup.TagUtils;
+import org.apache.wicket.markup.WicketTag;
+import org.apache.wicket.markup.html.internal.HtmlHeaderContainer;
+import org.apache.wicket.response.NullResponse;
+import org.apache.wicket.util.lang.Classes;
+import org.apache.wicket.util.value.IValueMap;
+
 
 /**
- * A Wicket internal helper class to handle wicket:head tags.
+ * A Wicket internal helper class to handle org.apache.wicket:head tags.
  * 
  * @author Juergen Donnerstag
  */
@@ -44,7 +45,7 @@
 	/** True if body onLoad attribute modifiers have been attached */
 	private boolean checkedBody = false;
 
-	/** <wicket:head> is only allowed before <body>, </head>, <wicket:panel> etc. */
+	/** <org.apache.wicket:head> is only allowed before <body>, </head>, <org.apache.wicket:panel> etc. */
 	private boolean noMoreWicketHeadTagsAllowed = false;
 
 	/** The markup container the helper is associated with */
@@ -60,7 +61,7 @@
 
 	/**
 	 * Called by components like Panel and Border which have associated Markup
-	 * and which may have a &lt;wicket:head&gt; tag.
+	 * and which may have a &lt;org.apache.wicket:head&gt; tag.
 	 * <p>
 	 * Whereas 'this' might be a Panel or Border, the HtmlHeaderContainer
 	 * parameter has been added to the Page as a container for all headers any
@@ -132,7 +133,7 @@
 				}
 			}
 
-			// Position the stream after <wicket:head>
+			// Position the stream after <org.apache.wicket:head>
 			markupStream.skipComponent();
 		}
 	}
@@ -195,9 +196,9 @@
 	 * @param index
 	 *            A unique index
 	 * @param markupClass
-	 *            The java class the wicket:head tag is directly associated with
+	 *            The java class the org.apache.wicket:head tag is directly associated with
 	 * @return the header part for this panel/border or null if it doesn't have
-	 *         a wicket:head tag.
+	 *         a org.apache.wicket:head tag.
 	 */
 	private final HeaderPartContainer getHeaderPart(final Class markupClass, final int index)
 	{
@@ -215,7 +216,7 @@
 			final WicketTag wTag = (WicketTag)element;
 			if ((wTag.isHeadTag() == true) && (wTag.getNamespace() != null))
 			{
-				// found <wicket:head>
+				// found <org.apache.wicket:head>
 				// create a unique id for the HtmlHeaderContainer to be
 				// created
 				final String headerId = "_" + Classes.simpleName(markupClass)
@@ -253,7 +254,7 @@
 			return -1;
 		}
 
-		// Scan the markup for <wicket:head>.
+		// Scan the markup for <org.apache.wicket:head>.
 		MarkupElement elem = associatedMarkupStream.get();
 		while (elem != null)
 		{
@@ -265,11 +266,11 @@
 					if (this.noMoreWicketHeadTagsAllowed == true)
 					{
 						throw new MarkupException(
-								"<wicket:head> tags are only allowed before <body>, </head>, <wicket:panel> etc. tag");
+								"<org.apache.wicket:head> tags are only allowed before <body>, </head>, <org.apache.wicket:panel> etc. tag");
 					}
 					return associatedMarkupStream.getCurrentIndex();
 				}
-				// wicket:head must be before border, panel or extend
+				// org.apache.wicket:head must be before border, panel or extend
 				else if (tag.isOpen()
 						&& (tag.isPanelTag() || tag.isBorderTag() || tag.isExtendTag()))
 				{
@@ -279,12 +280,12 @@
 			else if (elem instanceof ComponentTag)
 			{
 				ComponentTag tag = (ComponentTag)elem;
-				// wicket:head must be before </head>
+				// org.apache.wicket:head must be before </head>
 				if (tag.isClose() && TagUtils.isHeadTag(tag))
 				{
 					this.noMoreWicketHeadTagsAllowed = true;
 				}
-				// wicket:head must be before <body>
+				// org.apache.wicket:head must be before <body>
 				else if (tag.isOpen() && TagUtils.isBodyTag(tag))
 				{
 					this.noMoreWicketHeadTagsAllowed = true;
@@ -293,7 +294,7 @@
 			elem = associatedMarkupStream.next();
 		}
 
-		// No (more) wicket:head found
+		// No (more) org.apache.wicket:head found
 		return -1;
 	}
 }

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/DynamicWebResource.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/DynamicWebResource.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/DynamicWebResource.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/DynamicWebResource.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/DynamicWebResource.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/DynamicWebResource.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/DynamicWebResource.java Tue Apr 10 11:15:14 2007
@@ -14,17 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
 import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.Locale;
 
-import wicket.protocol.http.WebResponse;
-import wicket.util.resource.IResourceStream;
-import wicket.util.resource.ResourceStreamNotFoundException;
-import wicket.util.time.Time;
+import org.apache.wicket.protocol.http.WebResponse;
+import org.apache.wicket.util.resource.IResourceStream;
+import org.apache.wicket.util.resource.ResourceStreamNotFoundException;
+import org.apache.wicket.util.time.Time;
+
 
 /**
  * An WebResource subclass for dynamic resources (resources created
@@ -131,7 +132,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.WebResource#setHeaders(wicket.protocol.http.WebResponse)
+	 * @see org.apache.wicket.markup.html.WebResource#setHeaders(org.apache.wicket.protocol.http.WebResponse)
 	 */
 	protected void setHeaders(WebResponse response)
 	{
@@ -173,7 +174,7 @@
 			private transient ResourceState data = null;
 
 			/**
-			 * @see wicket.util.resource.IResourceStream#close()
+			 * @see org.apache.wicket.util.resource.IResourceStream#close()
 			 */
 			public void close() throws IOException
 			{
@@ -186,7 +187,7 @@
 			}
 
 			/**
-			 * @see wicket.util.resource.IResourceStream#getContentType()
+			 * @see org.apache.wicket.util.resource.IResourceStream#getContentType()
 			 */
 			public String getContentType()
 			{
@@ -195,7 +196,7 @@
 			}
 
 			/**
-			 * @see wicket.util.resource.IResourceStream#getInputStream()
+			 * @see org.apache.wicket.util.resource.IResourceStream#getInputStream()
 			 */
 			public InputStream getInputStream() throws ResourceStreamNotFoundException
 			{
@@ -208,7 +209,7 @@
 			}
 
 			/**
-			 * @see wicket.util.watch.IModifiable#lastModifiedTime()
+			 * @see org.apache.wicket.util.watch.IModifiable#lastModifiedTime()
 			 */
 			public Time lastModifiedTime()
 			{
@@ -217,7 +218,7 @@
 			}
 
 			/**
-			 * @see wicket.util.resource.IResourceStream#length()
+			 * @see org.apache.wicket.util.resource.IResourceStream#length()
 			 */
 			public long length()
 			{
@@ -226,7 +227,7 @@
 			}
 
 			/**
-			 * @see wicket.util.resource.IResourceStream#getLocale()
+			 * @see org.apache.wicket.util.resource.IResourceStream#getLocale()
 			 */
 			public Locale getLocale()
 			{
@@ -234,7 +235,7 @@
 			}
 
 			/**
-			 * @see wicket.util.resource.IResourceStream#setLocale(java.util.Locale)
+			 * @see org.apache.wicket.util.resource.IResourceStream#setLocale(java.util.Locale)
 			 */
 			public void setLocale(Locale loc)
 			{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/HeaderPartContainer.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/HeaderPartContainer.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/HeaderPartContainer.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/HeaderPartContainer.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/HeaderPartContainer.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/HeaderPartContainer.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/HeaderPartContainer.java Tue Apr 10 11:15:14 2007
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
-import wicket.Component;
-import wicket.MarkupContainer;
-import wicket.markup.ComponentTag;
-import wicket.markup.MarkupStream;
-import wicket.markup.resolver.IComponentResolver;
+import org.apache.wicket.Component;
+import org.apache.wicket.MarkupContainer;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.MarkupStream;
+import org.apache.wicket.markup.resolver.IComponentResolver;
 
 /**
- * For each wicket:head tag a HeaderPartContainer is created and added to
+ * For each org.apache.wicket:head tag a HeaderPartContainer is created and added to
  * the HtmlHeaderContainer which has been added to the Page.
  * 
  * @author Juergen Donnerstag
@@ -37,7 +37,7 @@
 	/** The panel or bordered page the header part is associated with */
 	private final MarkupContainer container;
 
-	/** <wicket:head scope="...">. A kind of namespace */
+	/** <org.apache.wicket:head scope="...">. A kind of namespace */
 	private final String scope;
 
 	/**
@@ -47,7 +47,7 @@
 	 *            The Panel (or bordered page) the header part is associated
 	 *            with
 	 * @param scope
-	 *            The scope of the wicket:head tag
+	 *            The scope of the org.apache.wicket:head tag
 	 */
 	public HeaderPartContainer(final String id, final MarkupContainer container,
 			final String scope)

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/IHeaderContributor.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/IHeaderContributor.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/IHeaderContributor.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/IHeaderContributor.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/IHeaderContributor.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/IHeaderContributor.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/IHeaderContributor.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
-import wicket.IClusterable;
+import org.apache.wicket.IClusterable;
 
 /**
  * An interface to be implemented by components which are able to render the

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/IHeaderPartContainerProvider.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/IHeaderPartContainerProvider.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/IHeaderPartContainerProvider.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/IHeaderPartContainerProvider.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/IHeaderPartContainerProvider.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/IHeaderPartContainerProvider.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/IHeaderPartContainerProvider.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
 /**
  * WebMarkupContainers that implement this know how to provide header parts for
- * wicket:head fragments.
+ * org.apache.wicket:head fragments.
  * 
  * @author eelcohillenius
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/IHeaderResponse.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/IHeaderResponse.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/IHeaderResponse.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/IHeaderResponse.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/IHeaderResponse.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/IHeaderResponse.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/IHeaderResponse.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
-import wicket.ResourceReference;
-import wicket.Response;
+import org.apache.wicket.ResourceReference;
+import org.apache.wicket.Response;
 
 /**
  * Interface that is used to render header elements (usually javascript and CSS

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/INewBrowserWindowListener.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/INewBrowserWindowListener.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/INewBrowserWindowListener.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/INewBrowserWindowListener.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/INewBrowserWindowListener.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/INewBrowserWindowListener.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/INewBrowserWindowListener.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
-import wicket.IRequestListener;
-import wicket.RequestListenerInterface;
+import org.apache.wicket.IRequestListener;
+import org.apache.wicket.RequestListenerInterface;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/IPackageResourceGuard.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/IPackageResourceGuard.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/IPackageResourceGuard.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/IPackageResourceGuard.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/IPackageResourceGuard.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/IPackageResourceGuard.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/IPackageResourceGuard.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/JavascriptPackageResource.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/JavascriptPackageResource.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/JavascriptPackageResource.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/JavascriptPackageResource.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/JavascriptPackageResource.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/JavascriptPackageResource.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/JavascriptPackageResource.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
@@ -25,14 +25,14 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Application;
+import org.apache.wicket.SharedResources;
+import org.apache.wicket.util.io.Streams;
+import org.apache.wicket.util.resource.IResourceStream;
+import org.apache.wicket.util.resource.ResourceStreamNotFoundException;
+import org.apache.wicket.util.string.JavascriptStripper;
+import org.apache.wicket.util.time.Time;
 
-import wicket.Application;
-import wicket.SharedResources;
-import wicket.util.io.Streams;
-import wicket.util.resource.IResourceStream;
-import wicket.util.resource.ResourceStreamNotFoundException;
-import wicket.util.string.JavascriptStripper;
-import wicket.util.time.Time;
 
 /**
  * Package resource for javascript files. It strips comments and whitespaces
@@ -59,14 +59,14 @@
 		private Time timeStamp = null;
 
 		/**
-		 * @see wicket.util.resource.IResourceStream#close()
+		 * @see org.apache.wicket.util.resource.IResourceStream#close()
 		 */
 		public void close() throws IOException
 		{
 		}
 
 		/**
-		 * @see wicket.util.resource.IResourceStream#getContentType()
+		 * @see org.apache.wicket.util.resource.IResourceStream#getContentType()
 		 */
 		public String getContentType()
 		{
@@ -74,7 +74,7 @@
 		}
 
 		/**
-		 * @see wicket.util.resource.IResourceStream#getInputStream()
+		 * @see org.apache.wicket.util.resource.IResourceStream#getInputStream()
 		 */
 		public InputStream getInputStream() throws ResourceStreamNotFoundException
 		{
@@ -82,7 +82,7 @@
 		}
 
 		/**
-		 * @see wicket.util.resource.IResourceStream#getLocale()
+		 * @see org.apache.wicket.util.resource.IResourceStream#getLocale()
 		 */
 		public Locale getLocale()
 		{
@@ -90,7 +90,7 @@
 		}
 
 		/**
-		 * @see wicket.util.watch.IModifiable#lastModifiedTime()
+		 * @see org.apache.wicket.util.watch.IModifiable#lastModifiedTime()
 		 */
 		public Time lastModifiedTime()
 		{
@@ -98,7 +98,7 @@
 		}
 
 		/**
-		 * @see wicket.util.resource.IResourceStream#length()
+		 * @see org.apache.wicket.util.resource.IResourceStream#length()
 		 */
 		public long length()
 		{
@@ -106,7 +106,7 @@
 		}
 
 		/**
-		 * @see wicket.util.resource.IResourceStream#setLocale(java.util.Locale)
+		 * @see org.apache.wicket.util.resource.IResourceStream#setLocale(java.util.Locale)
 		 */
 		public void setLocale(Locale locale)
 		{
@@ -171,7 +171,7 @@
 	 * @param locale
 	 *            The locale of the resource
 	 * @param style
-	 *            The style of the resource (see {@link wicket.Session})
+	 *            The style of the resource (see {@link org.apache.wicket.Session})
 	 * @return The resource
 	 * @throws PackageResourceBlockedException
 	 *             when the target resource is not accepted by
@@ -207,7 +207,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.CompressedPackageResource#newResourceStream()
+	 * @see org.apache.wicket.markup.html.CompressedPackageResource#newResourceStream()
 	 */
 	protected IResourceStream newResourceStream()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/PackageResource.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/PackageResource.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/PackageResource.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/PackageResource.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/PackageResource.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/PackageResource.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/PackageResource.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
 import java.io.File;
 import java.io.IOException;
@@ -35,18 +35,18 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.AbortException;
+import org.apache.wicket.Application;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.SharedResources;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.protocol.http.WebRequestCycle;
+import org.apache.wicket.protocol.http.servlet.AbortWithWebErrorCodeException;
+import org.apache.wicket.util.lang.PackageName;
+import org.apache.wicket.util.lang.Packages;
+import org.apache.wicket.util.resource.IResourceStream;
+import org.apache.wicket.util.string.Strings;
 
-import wicket.AbortException;
-import wicket.Application;
-import wicket.RequestCycle;
-import wicket.SharedResources;
-import wicket.WicketRuntimeException;
-import wicket.protocol.http.WebRequestCycle;
-import wicket.protocol.http.servlet.AbortWithWebErrorCodeException;
-import wicket.util.lang.PackageName;
-import wicket.util.lang.Packages;
-import wicket.util.resource.IResourceStream;
-import wicket.util.string.Strings;
 
 /**
  * Represents a localizable static resource.
@@ -252,7 +252,7 @@
 	 * @param locale
 	 *            The locale of the resource
 	 * @param style
-	 *            The style of the resource (see {@link wicket.Session})
+	 *            The style of the resource (see {@link org.apache.wicket.Session})
 	 * @return true if a resource could be loaded, false otherwise
 	 */
 	public static boolean exists(final Class scope, final String path, final Locale locale,
@@ -408,7 +408,7 @@
 	 * @param locale
 	 *            The locale of the resource
 	 * @param style
-	 *            The style of the resource (see {@link wicket.Session})
+	 *            The style of the resource (see {@link org.apache.wicket.Session})
 	 * @return The resource
 	 */
 	public static PackageResource get(final Class scope, final String path, final Locale locale,

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/PackageResourceGuard.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/PackageResourceGuard.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/PackageResourceGuard.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/PackageResourceGuard.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/PackageResourceGuard.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/PackageResourceGuard.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/PackageResourceGuard.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
 import java.util.HashSet;
 import java.util.Set;
 
-import wicket.util.lang.Packages;
+import org.apache.wicket.util.lang.Packages;
+
 
 /**
  * Default implementation of {@link IPackageResourceGuard}. By default, the
@@ -43,7 +44,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.IPackageResourceGuard#accept(java.lang.Class,
+	 * @see org.apache.wicket.markup.html.IPackageResourceGuard#accept(java.lang.Class,
 	 *      java.lang.String)
 	 */
 	public boolean accept(Class scope, String path)

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/PackageResourceReference.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/PackageResourceReference.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/PackageResourceReference.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/PackageResourceReference.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/PackageResourceReference.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/PackageResourceReference.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/PackageResourceReference.java Tue Apr 10 11:15:14 2007
@@ -14,13 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
 import java.util.Locale;
 
-import wicket.Application;
-import wicket.Resource;
-import wicket.ResourceReference;
+import org.apache.wicket.Application;
+import org.apache.wicket.Resource;
+import org.apache.wicket.ResourceReference;
+
 
 /**
  * A convenience class for creating resource references to static resources.
@@ -92,8 +93,8 @@
 	/**
 	 * Constuctor to get a resource reference to a packaged resource.
 	 * 
-	 * The scope of this constructor will be the wicket.Application.class
-	 * itself. so the shared resources key wil be "wicket.Application/name"
+	 * The scope of this constructor will be the org.apache.wicket.Application.class
+	 * itself. so the shared resources key wil be "org.apache.wicket.Application/name"
 	 * 
 	 * @param application
 	 *            The application to bind to
@@ -154,7 +155,7 @@
 	}
 
 	/**
-	 * @see wicket.ResourceReference#newResource()
+	 * @see org.apache.wicket.ResourceReference#newResource()
 	 */
 	protected Resource newResource()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/ServerAndClientTimeFilter.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/ServerAndClientTimeFilter.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/ServerAndClientTimeFilter.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/ServerAndClientTimeFilter.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/ServerAndClientTimeFilter.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/ServerAndClientTimeFilter.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/ServerAndClientTimeFilter.java Tue Apr 10 11:15:14 2007
@@ -14,20 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
 import java.util.HashMap;
 import java.util.Map;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Application;
+import org.apache.wicket.IResponseFilter;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.model.Model;
+import org.apache.wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.util.string.JavascriptUtils;
 
-import wicket.Application;
-import wicket.IResponseFilter;
-import wicket.RequestCycle;
-import wicket.model.Model;
-import wicket.util.string.AppendingStringBuffer;
-import wicket.util.string.JavascriptUtils;
 
 /**
  * This is a filter that injects javascript code to the top head portion and
@@ -47,7 +47,7 @@
 	private static final Log log = LogFactory.getLog(ServerAndClientTimeFilter.class);
 
 	/**
-	 * @see wicket.IResponseFilter#filter(AppendingStringBuffer)
+	 * @see org.apache.wicket.IResponseFilter#filter(AppendingStringBuffer)
 	 */
 	public AppendingStringBuffer filter(AppendingStringBuffer responseBuffer)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/ServerTimeFilter.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/ServerTimeFilter.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/ServerTimeFilter.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/ServerTimeFilter.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/ServerTimeFilter.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/ServerTimeFilter.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/ServerTimeFilter.java Tue Apr 10 11:15:14 2007
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.IResponseFilter;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.util.string.JavascriptUtils;
 
-import wicket.IResponseFilter;
-import wicket.RequestCycle;
-import wicket.util.string.AppendingStringBuffer;
-import wicket.util.string.JavascriptUtils;
 
 /**
  * This filter logs the server time so the time it takes from the start of a
@@ -39,7 +39,7 @@
 	private static final Log log = LogFactory.getLog(ServerTimeFilter.class);
 
 	/**
-	 * @see wicket.IResponseFilter#filter(AppendingStringBuffer)
+	 * @see org.apache.wicket.IResponseFilter#filter(AppendingStringBuffer)
 	 */
 	public AppendingStringBuffer filter(AppendingStringBuffer responseBuffer)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/WebComponent.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/WebComponent.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/WebComponent.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/WebComponent.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/WebComponent.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/WebComponent.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/WebComponent.java Tue Apr 10 11:15:14 2007
@@ -14,18 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
-import wicket.Component;
-import wicket.markup.MarkupStream;
-import wicket.model.IModel;
+import org.apache.wicket.Component;
+import org.apache.wicket.markup.MarkupStream;
+import org.apache.wicket.model.IModel;
 
 /**
  * Base class for simple HTML components which do not hold nested components. If
  * you need to support nested components, see WebMarkupContainer or use Panel if
  * the component will have its own associated markup.
  * 
- * @see wicket.markup.html.WebMarkupContainer
+ * @see org.apache.wicket.markup.html.WebMarkupContainer
  * 
  * @author Jonathan Locke
  * @author Juergen Donnerstag
@@ -53,7 +53,7 @@
 
 	/**
 	 * 
-	 * @see wicket.Component#onRender(wicket.markup.MarkupStream)
+	 * @see org.apache.wicket.Component#onRender(org.apache.wicket.markup.MarkupStream)
 	 */
 	protected void onRender(final MarkupStream markupStream)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/WebMarkupContainer.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/WebMarkupContainer.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/WebMarkupContainer.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/WebMarkupContainer.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/WebMarkupContainer.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/WebMarkupContainer.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/WebMarkupContainer.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
-import wicket.Component;
-import wicket.MarkupContainer;
-import wicket.model.IModel;
+import org.apache.wicket.Component;
+import org.apache.wicket.MarkupContainer;
+import org.apache.wicket.model.IModel;
 
 /**
  * A container of HTML markup and components. It is very similar to the base
@@ -40,7 +40,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#Component(String, IModel)
+	 * @see org.apache.wicket.Component#Component(String, IModel)
 	 */
 	public WebMarkupContainer(final String id, IModel model)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/WebMarkupContainerWithAssociatedMarkup.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/WebMarkupContainerWithAssociatedMarkup.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/WebMarkupContainerWithAssociatedMarkup.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/WebMarkupContainerWithAssociatedMarkup.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/WebMarkupContainerWithAssociatedMarkup.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MarkupStream.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MarkupStream.java Tue Apr 10 11:15:14 2007
@@ -14,16 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
 import java.util.Iterator;
 
-import wicket.util.resource.IResourceStream;
-import wicket.util.string.Strings;
+import org.apache.wicket.util.resource.IResourceStream;
+import org.apache.wicket.util.string.Strings;
+
 
 /**
  * A stream of {@link wicket.markup.MarkupElement}s, subclases of which are
  * {@link wicket.markup.ComponentTag} and {@link wicket.markup.RawMarkup}. A
  * markup stream has a current index in the list of markup elements. The next
  * markup element can be retrieved and the index advanced by calling next(). If
  * the index hits the end, hasMore() will return false.
@@ -253,11 +254,11 @@
 	}
 
 	/**
 	 * Skips any markup at the current position until the wicket tag name is
 	 * found.
 	 * 
 	 * @param wicketTagName
 	 *            wicket tag name to seek
 	 */
 	public void skipUntil(final String wicketTagName)
 	{
@@ -394,9 +395,9 @@
 	}
 
 	/**
 	 * Get the wicket namespace valid for this specific markup
 	 * 
-	 * @return wicket namespace
+	 * @return org.apache.wicket namespace
 	 */
 	public final String getWicketNamespace()
 	{
@@ -14,16 +14,17 @@
 
 /**
- * A stream of {@link wicket.markup.MarkupElement}s, subclases of which are
- * {@link wicket.markup.ComponentTag} and {@link wicket.markup.RawMarkup}. A
+ * A stream of {@link org.apache.wicket.markup.MarkupElement}s, subclases of which are
+ * {@link org.apache.wicket.markup.ComponentTag} and {@link org.apache.wicket.markup.RawMarkup}. A
  * markup stream has a current index in the list of markup elements. The next
  * markup element can be retrieved and the index advanced by calling next(). If
@@ -253,11 +254,11 @@
 
 	/**
-	 * Skips any markup at the current position until the wicket tag name is
+	 * Skips any markup at the current position until the org.apache.wicket tag name is
 	 * found.
 	 * 
@@ -253,11 +254,11 @@
 	 * 
 	 * @param wicketTagName
-	 *            wicket tag name to seek
+	 *            org.apache.wicket tag name to seek
 	 */
 	public void skipUntil(final String wicketTagName)
@@ -394,9 +395,9 @@
 
 	/**
-	 * Get the wicket namespace valid for this specific markup
+	 * Get the org.apache.wicket namespace valid for this specific markup
 	 * 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MergedMarkup.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MergedMarkup.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MergedMarkup.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MergedMarkup.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MergedMarkup.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/MergedMarkup.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/MergedMarkup.java Tue Apr 10 11:15:14 2007
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup;
+package org.apache.wicket.markup;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Page;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.markup.parser.XmlTag;
+import org.apache.wicket.markup.parser.filter.HtmlHeaderSectionHandler;
+import org.apache.wicket.util.string.Strings;
 
-import wicket.Page;
-import wicket.WicketRuntimeException;
-import wicket.markup.parser.XmlTag;
-import wicket.markup.parser.filter.HtmlHeaderSectionHandler;
-import wicket.util.string.Strings;
 
 /**
  * A Markup class which represents merged markup, as it is required for markup
@@ -35,11 +35,11 @@
  * The markup resource file, which is associated with the markup, will be the
  * resource of the requested markup file. The base markup resources are not.
  * <p>
  * Base Markup must have a &lt;wicket:hild/&gt; tag which the position where the
  * derived markup is inserted. From the derived markup all tags in between
  * &lt;wicket:extend&gt; and &lt;/wicket:extend&gt; will be inserted.
  * <p>
  * In addition, all &lt;wicket:head> regions are copied as well as the body
  * onLoad attribute. This allows to develop completely self-contained plug &
  * play components including javascript etc.
  * 
@@ -57,7 +57,7 @@
 	 * @param baseMarkup
 	 *            The base markup
 	 * @param extendIndex
 	 *            Index where <wicket:extend> has been found
 	 */
 	MergedMarkup(final Markup markup, final Markup baseMarkup, int extendIndex)
 	{
@@ -97,7 +97,7 @@
 	{
 		int i = 0;
 
 		// The markup must have a <wicket:head> region, else copying the
 		// body onLoad attributes doesn't make sense
 		for (; i < markup.size(); i++)
 		{
@@ -107,13 +107,13 @@
 				WicketTag tag = (WicketTag)elem;
 				if (tag.isClose() && tag.isHeadTag())
 				{
 					// Ok, we found <wicket:head>
 					break;
 				}
 				else if (tag.isMajorWicketComponentTag())
 				{
 					// Short cut: We found <wicket:panel> or <wicket:border>.
 					// There certainly will be no <wicket:head> later on.
 					return null;
 				}
 			}
@@ -122,14 +122,14 @@
 				ComponentTag tag = (ComponentTag)elem;
 				if (TagUtils.isBodyTag(tag))
 				{
 					// Short cut: We found <body> but no <wicket:head>.
 					// There certainly will be no <wicket:head> later on.
 					return null;
 				}
 			}
 		}
 
 		// Found </wicket:head> => get body onLoad
 		for (; i < markup.size(); i++)
 		{
 			MarkupElement elem = markup.get(i);
@@ -155,16 +155,16 @@
 	 * @param baseMarkup
 	 *            The base markup
 	 * @param extendIndex
 	 *            Index where <wicket:extend> has been found
 	 */
 	private void merge(final Markup markup, final Markup baseMarkup, int extendIndex)
 	{
 		// True if either <wicket:head> or <head> has been processed
 		boolean wicketHeadProcessed = false;
 
 		// Add all elements from the base markup to the new list
 		// until <wicket:child/> is found. Convert <wicket:child/>
 		// into <wicket:child> and add it as well.
 		WicketTag childTag = null;
 		int baseIndex = 0;
 		for (; baseIndex < baseMarkup.size(); baseIndex++)
@@ -190,7 +190,7 @@
 			{
 				WicketTag wtag = (WicketTag)element;
 
 				// Found wicket.child in base markup. In case of 3+ level
 				// inheritance make sure the child tag is not from one of the
 				// deeper levels
 				if (wtag.isChildTag()
@@ -198,7 +198,7 @@
 				{
 					if (wtag.isOpenClose())
 					{
-						// <wicket:child /> => <wicket:child>...</wicket:child>
+						// <org.apache.wicket:child /> => <org.apache.wicket:child>...</org.apache.wicket:child>
 						childTag = wtag;
 						WicketTag childOpenTag = (WicketTag)wtag.mutable();
 						childOpenTag.getXmlTag().setType(XmlTag.OPEN);
@@ -208,13 +208,13 @@
 					}
 					else if (wtag.isOpen())
 					{
-						// <wicket:child>
+						// <org.apache.wicket:child>
 						addMarkupElement(wtag);
 						break;
 					}
 					else
 					{
-						throw new WicketRuntimeException("Did not expect a </wicket:child> tag in "
+						throw new WicketRuntimeException("Did not expect a </org.apache.wicket:child> tag in "
 								+ baseMarkup.toString());
 					}
 				}
@@ -222,7 +222,7 @@
 				// Process the head of the extended markup only once
 				if (wicketHeadProcessed == false)
 				{
-					// if </wicket:head> in base markup
+					// if </org.apache.wicket:head> in base markup
 					if (wtag.isClose() && wtag.isHeadTag())
 					{
 						wicketHeadProcessed = true;
@@ -230,7 +230,7 @@
 						// Add the current close tag
 						addMarkupElement(wtag);
 
 						// Add the <wicket:head> body from the derived markup.
 						copyWicketHead(markup, extendIndex);
 
 						// Do not add the current tag. It has already been
@@ -238,12 +238,12 @@
 						continue;
 					}
 
-					// if <wicket:panel> or ... in base markup
+					// if <org.apache.wicket:panel> or ... in base markup
 					if (wtag.isOpen() && wtag.isMajorWicketComponentTag())
 					{
 						wicketHeadProcessed = true;
 
 						// Add the <wicket:head> body from the derived markup.
 						copyWicketHead(markup, extendIndex);
 					}
 				}
@@ -258,7 +258,7 @@
 				{
 					wicketHeadProcessed = true;
 
 					// Add the <wicket:head> body from the derived markup.
 					copyWicketHead(markup, extendIndex);
 				}
 			}
@@ -295,12 +295,12 @@
 
 		if (baseIndex == baseMarkup.size())
 		{
-			throw new WicketRuntimeException("Expected to find <wicket:child/> in base markup: "
+			throw new WicketRuntimeException("Expected to find <org.apache.wicket:child/> in base markup: "
 					+ baseMarkup.toString());
 		}
 
 		// Now append all elements from the derived markup starting with
 		// <wicket:extend> until </wicket:extend> to the list
 		for (; extendIndex < markup.size(); extendIndex++)
 		{
 			MarkupElement element = markup.get(extendIndex);
@@ -319,10 +319,10 @@
 		if (extendIndex == markup.size())
 		{
 			throw new WicketRuntimeException(
-					"Missing close tag </wicket:extend> in derived markup: " + markup.toString());
+					"Missing close tag </org.apache.wicket:extend> in derived markup: " + markup.toString());
 		}
 
 		// If <wicket:child> than skip the body and find </wicket:child>
 		if (((ComponentTag)baseMarkup.get(baseIndex)).isOpen())
 		{
 			for (baseIndex++; baseIndex < baseMarkup.size(); baseIndex++)
@@ -341,29 +341,29 @@
 					else
 					{
 						throw new WicketRuntimeException(
-								"Wicket tags like <wicket:xxx> are not allowed in between <wicket:child> and </wicket:child> tags: "
+								"Wicket tags like <org.apache.wicket:xxx> are not allowed in between <org.apache.wicket:child> and </org.apache.wicket:child> tags: "
 										+ markup.toString());
 					}
 				}
 				else if (element instanceof ComponentTag)
 				{
 					throw new WicketRuntimeException(
-							"Wicket tags identified by wicket:id are not allowed in between <wicket:child> and </wicket:child> tags: "
+							"Wicket tags identified by wicket:id are not allowed in between <org.apache.wicket:child> and </org.apache.wicket:child> tags: "
 									+ markup.toString());
 				}
 			}
 
-			// </wicket:child> not found
+			// </org.apache.wicket:child> not found
 			if (baseIndex == baseMarkup.size())
 			{
 				throw new WicketRuntimeException(
-						"Expected to find </wicket:child> in base markup: " + baseMarkup.toString());
+						"Expected to find </org.apache.wicket:child> in base markup: " + baseMarkup.toString());
 			}
 		}
 		else
 		{
 			// And now all remaining elements from the derived markup.
 			// But first add </wicket:child>
 			WicketTag childCloseTag = (WicketTag)childTag.mutable();
 			childCloseTag.getXmlTag().setType(XmlTag.CLOSE);
 			childCloseTag.setMarkupClass(baseMarkup.getResource().getMarkupClass());
@@ -385,13 +385,13 @@
 		}
 
 		// Automatically add <head> if missing and required. On a Page
 		// it must enclose ALL of the <wicket:head> tags.
 		// Note: HtmlHeaderSectionHandler does something similar, but because
 		// markup filters are not called for merged markup again, ...
 		if (Page.class.isAssignableFrom(markup.getResource().getMarkupClass()))
 		{
 			// Find the position inside the markup for first <wicket:head>,
 			// last </wicket:head> and <head>
 			int hasOpenWicketHead = -1;
 			int hasCloseWicketHead = -1;
 			int hasHead = -1;
@@ -443,7 +443,7 @@
 	}
 
 	/**
 	 * Append the wicket:head regions from the extended markup to the current
 	 * markup
 	 * 
 	 * @param markup
@@ -35,11 +35,11 @@
  * resource of the requested markup file. The base markup resources are not.
  * <p>
- * Base Markup must have a &lt;wicket:hild/&gt; tag which the position where the
+ * Base Markup must have a &lt;org.apache.wicket:hild/&gt; tag which the position where the
  * derived markup is inserted. From the derived markup all tags in between
@@ -35,11 +35,11 @@
  * derived markup is inserted. From the derived markup all tags in between
- * &lt;wicket:extend&gt; and &lt;/wicket:extend&gt; will be inserted.
+ * &lt;org.apache.wicket:extend&gt; and &lt;/org.apache.wicket:extend&gt; will be inserted.
  * <p>
@@ -35,11 +35,11 @@
  * <p>
- * In addition, all &lt;wicket:head> regions are copied as well as the body
+ * In addition, all &lt;org.apache.wicket:head> regions are copied as well as the body
  * onLoad attribute. This allows to develop completely self-contained plug &
  * play components including javascript etc.
@@ -57,7 +57,7 @@
 	 *            The base markup
 	 * @param extendIndex
-	 *            Index where <wicket:extend> has been found
+	 *            Index where <org.apache.wicket:extend> has been found
 	 */
 	MergedMarkup(final Markup markup, final Markup baseMarkup, int extendIndex)
@@ -97,7 +97,7 @@
 		int i = 0;
 
-		// The markup must have a <wicket:head> region, else copying the
+		// The markup must have a <org.apache.wicket:head> region, else copying the
 		// body onLoad attributes doesn't make sense
 		for (; i < markup.size(); i++)
@@ -107,13 +107,13 @@
 				if (tag.isClose() && tag.isHeadTag())
 				{
-					// Ok, we found <wicket:head>
+					// Ok, we found <org.apache.wicket:head>
 					break;
 				}
@@ -107,13 +107,13 @@
 				else if (tag.isMajorWicketComponentTag())
 				{
-					// Short cut: We found <wicket:panel> or <wicket:border>.
-					// There certainly will be no <wicket:head> later on.
+					// Short cut: We found <org.apache.wicket:panel> or <org.apache.wicket:border>.
+					// There certainly will be no <org.apache.wicket:head> later on.
 					return null;
 				}
@@ -122,14 +122,14 @@
 				if (TagUtils.isBodyTag(tag))
 				{
-					// Short cut: We found <body> but no <wicket:head>.
-					// There certainly will be no <wicket:head> later on.
+					// Short cut: We found <body> but no <org.apache.wicket:head>.
+					// There certainly will be no <org.apache.wicket:head> later on.
 					return null;
 				}
@@ -122,14 +122,14 @@
 		}
 
-		// Found </wicket:head> => get body onLoad
+		// Found </org.apache.wicket:head> => get body onLoad
 		for (; i < markup.size(); i++)
 		{
@@ -155,16 +155,16 @@
 	 *            The base markup
 	 * @param extendIndex
-	 *            Index where <wicket:extend> has been found
+	 *            Index where <org.apache.wicket:extend> has been found
 	 */
 	private void merge(final Markup markup, final Markup baseMarkup, int extendIndex)
@@ -155,16 +155,16 @@
 	private void merge(final Markup markup, final Markup baseMarkup, int extendIndex)
 	{
-		// True if either <wicket:head> or <head> has been processed
+		// True if either <org.apache.wicket:head> or <head> has been processed
 		boolean wicketHeadProcessed = false;
 
@@ -155,16 +155,16 @@
 
 		// Add all elements from the base markup to the new list
-		// until <wicket:child/> is found. Convert <wicket:child/>
-		// into <wicket:child> and add it as well.
+		// until <org.apache.wicket:child/> is found. Convert <org.apache.wicket:child/>
+		// into <org.apache.wicket:child> and add it as well.
 		WicketTag childTag = null;
 		int baseIndex = 0;
@@ -190,7 +190,7 @@
 				WicketTag wtag = (WicketTag)element;
 
-				// Found wicket.child in base markup. In case of 3+ level
+				// Found org.apache.wicket.child in base markup. In case of 3+ level
 				// inheritance make sure the child tag is not from one of the
 				// deeper levels
@@ -230,7 +230,7 @@
 						addMarkupElement(wtag);
 
-						// Add the <wicket:head> body from the derived markup.
+						// Add the <org.apache.wicket:head> body from the derived markup.
 						copyWicketHead(markup, extendIndex);
 
@@ -238,12 +238,12 @@
 						wicketHeadProcessed = true;
 
-						// Add the <wicket:head> body from the derived markup.
+						// Add the <org.apache.wicket:head> body from the derived markup.
 						copyWicketHead(markup, extendIndex);
 					}
@@ -258,7 +258,7 @@
 					wicketHeadProcessed = true;
 
-					// Add the <wicket:head> body from the derived markup.
+					// Add the <org.apache.wicket:head> body from the derived markup.
 					copyWicketHead(markup, extendIndex);
 				}
@@ -295,12 +295,12 @@
 
 		// Now append all elements from the derived markup starting with
-		// <wicket:extend> until </wicket:extend> to the list
+		// <org.apache.wicket:extend> until </org.apache.wicket:extend> to the list
 		for (; extendIndex < markup.size(); extendIndex++)
 		{
@@ -319,10 +319,10 @@
 		}
 
-		// If <wicket:child> than skip the body and find </wicket:child>
+		// If <org.apache.wicket:child> than skip the body and find </org.apache.wicket:child>
 		if (((ComponentTag)baseMarkup.get(baseIndex)).isOpen())
 		{
@@ -341,29 +341,29 @@
 		{
 			// And now all remaining elements from the derived markup.
-			// But first add </wicket:child>
+			// But first add </org.apache.wicket:child>
 			WicketTag childCloseTag = (WicketTag)childTag.mutable();
 			childCloseTag.getXmlTag().setType(XmlTag.CLOSE);
@@ -385,13 +385,13 @@
 
 		// Automatically add <head> if missing and required. On a Page
-		// it must enclose ALL of the <wicket:head> tags.
+		// it must enclose ALL of the <org.apache.wicket:head> tags.
 		// Note: HtmlHeaderSectionHandler does something similar, but because
 		// markup filters are not called for merged markup again, ...
@@ -385,13 +385,13 @@
 		if (Page.class.isAssignableFrom(markup.getResource().getMarkupClass()))
 		{
-			// Find the position inside the markup for first <wicket:head>,
-			// last </wicket:head> and <head>
+			// Find the position inside the markup for first <org.apache.wicket:head>,
+			// last </org.apache.wicket:head> and <head>
 			int hasOpenWicketHead = -1;
 			int hasCloseWicketHead = -1;
@@ -443,7 +443,7 @@
 
 	/**
-	 * Append the wicket:head regions from the extended markup to the current
+	 * Append the org.apache.wicket:head regions from the extended markup to the current
 	 * markup
 	 * 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/RawMarkup.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/RawMarkup.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/RawMarkup.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/RawMarkup.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/RawMarkup.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/WebMarkupContainerWithAssociatedMarkup.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/WebMarkupContainerWithAssociatedMarkup.java Tue Apr 10 11:15:14 2007
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html;
+package org.apache.wicket.markup.html;
 
-import wicket.Component;
-import wicket.markup.html.internal.HtmlHeaderContainer;
-import wicket.model.IModel;
+import org.apache.wicket.Component;
+import org.apache.wicket.markup.html.internal.HtmlHeaderContainer;
+import org.apache.wicket.model.IModel;
 
 /**
  * WebMarkupContainer with it's own markup and possibly <wicket:head> tag.
  * 
  * @author Juergen Donnerstag
  */
@@ -43,7 +43,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#Component(String, IModel)
+	 * @see org.apache.wicket.Component#Component(String, IModel)
 	 */
 	public WebMarkupContainerWithAssociatedMarkup(final String id, IModel model)
 	{
@@ -52,7 +52,7 @@
 
 	/**
 	 * Called by components like Panel and Border which have associated Markup
 	 * and which may have a &lt;wicket:head&gt; tag.
 	 * <p>
 	 * Whereas 'this' might be a Panel or Border, the HtmlHeaderContainer
 	 * parameter has been added to the Page as a container for all headers any
@@ -74,7 +74,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.IHeaderPartContainerProvider#newHeaderPartContainer(java.lang.String,
+	 * @see org.apache.wicket.markup.html.IHeaderPartContainerProvider#newHeaderPartContainer(java.lang.String,
 	 *      java.lang.String)
 	 */
 	public HeaderPartContainer newHeaderPartContainer(final String id, final String scope)
@@ -14,14 +14,14 @@
 
 /**
- * WebMarkupContainer with it's own markup and possibly <wicket:head> tag.
+ * WebMarkupContainer with it's own markup and possibly <org.apache.wicket:head> tag.
  * 
  * @author Juergen Donnerstag
@@ -52,7 +52,7 @@
 	/**
 	 * Called by components like Panel and Border which have associated Markup
-	 * and which may have a &lt;wicket:head&gt; tag.
+	 * and which may have a &lt;org.apache.wicket:head&gt; tag.
 	 * <p>
 	 * Whereas 'this' might be a Panel or Border, the HtmlHeaderContainer